@@ -20,7 +20,6 @@
 #include <QtSvg/QSvgRenderer>
 #include <QtGui/QColorDialog>
 
-#include "AbstractProjection.h"
 #include "MarbleDirs.h"
 #include "MarbleDebug.h"
 #include "MarbleModel.h"
@@ -134,7 +133,7 @@ bool OverviewMap::isInitialized () const
 
 void OverviewMap::changeViewport( ViewportParams *viewport )
 {
-    GeoDataLatLonAltBox latLonAltBox = viewport->currentProjection()->latLonAltBox( QRect( QPoint( 0, 0 ), viewport->size() ), viewport );
+    GeoDataLatLonAltBox latLonAltBox = viewport->latLonAltBox( QRect( QPoint( 0, 0 ), viewport->size() ) );
     const qreal centerLon = viewport->centerLongitude();
     const qreal centerLat = viewport->centerLatitude();
     QString target = marbleModel()->planetId();
